@@ -3,7 +3,9 @@
         - Class which manages reader tasks like auth, requests, pagination
 """
 import json
+
 from azure.storage.blob import ContainerClient
+from azure.core.exceptions import ResourceNotFoundError
 
 
 class CustomAzureReader():
@@ -36,5 +38,15 @@ class CustomAzureReader():
             Pulls the data file from Azure blob
             :return: storage downloader object
         """
-        byte_sequence = self.container_client.download_blob(file_name).readall()
-        return json.loads(byte_sequence.decode("utf-8"))
+        try:
+            byte_sequence = self.container_client.download_blob(file_name).readall()
+            return json.loads(byte_sequence.decode("utf-8"))
+        except ResourceNotFoundError as exception:
+            print(
+                'Could not find specified blob: {exception}'.format(
+                    exception=str(exception)
+                )
+            )
+
+            return None
+
